==> percona-server-5.7_5.7.32-35.orig.tar.gz: percona-server-5.7.32-35/storage/ndb/include/util/SocketAuthenticator.hpp <==
/*
   Copyright (c) 2004, 2012, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef SOCKET_AUTHENTICATOR_HPP
#define SOCKET_AUTHENTICATOR_HPP

#include <NdbTCP.h>

class SocketAuthenticator
{
public:
  SocketAuthenticator() {}
  virtual ~SocketAuthenticator() {};
  virtual bool client_authenticate(NDB_SOCKET_TYPE sockfd) = 0;
  virtual bool server_authenticate(NDB_SOCKET_TYPE sockfd) = 0;
};

class SocketAuthSimple : public SocketAuthenticator
{
  char *m_passwd;
  char *m_username;
public:
  SocketAuthSimple(const char *username, const char *passwd);
  virtual ~SocketAuthSimple();
  virtual bool client_authenticate(NDB_SOCKET_TYPE sockfd);
  virtual bool server_authenticate(NDB_SOCKET_TYPE sockfd);
};

#endif // SOCKET_AUTHENTICATOR_HPP

==> percona-server-8.0.15-6.tar.gz: percona-server-8.0.15-6/storage/ndb/include/util/SocketAuthenticator.hpp <==
/*
   Copyright (c) 2004, 2018, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef SOCKET_AUTHENTICATOR_HPP
#define SOCKET_AUTHENTICATOR_HPP

#include <NdbTCP.h>

class SocketAuthenticator
{
public:
  SocketAuthenticator() {}
  virtual ~SocketAuthenticator() {}
  virtual bool client_authenticate(NDB_SOCKET_TYPE sockfd) = 0;
  virtual bool server_authenticate(NDB_SOCKET_TYPE sockfd) = 0;
};

class SocketAuthSimple : public SocketAuthenticator
{
  char *m_passwd;
  char *m_username;
public:
  SocketAuthSimple(const char *username, const char *passwd);
  virtual ~SocketAuthSimple();
  virtual bool client_authenticate(NDB_SOCKET_TYPE sockfd);
  virtual bool server_authenticate(NDB_SOCKET_TYPE sockfd);
};

#endif // SOCKET_AUTHENTICATOR_HPP
